integrate_poisson_boltzmann_1D<-function(charge_density,delta_x=1e-10,intrinsic_charge_density=1e7,er=78,phi0=0,dphidx0=0,Temperature=293)
{

	# This is an integration function, it solves the Poisson-Boltzmann for known initial conditions in terms of phi and dphidx at x=0
	# No particular other boundary conditions are implied, but obtaining a correct solution needs very precise knowledge of phi0 and dphidx0
	# Charge density in C/m^3, but c_intrinsic in mol/L
	
	# The theory is er*epsilon0*d^2phi/dx^2 = -charge_density
	# So we need, dphidx and d2phid2x; also we assume phi[1]=0 by definition
	
	
	# First, define some fundamental constants
	
	epsilon0=8.854187817e-12
	
	# Initialize everything at zero
	
	zeroes = vector(mode="numeric",length=length(charge_density))
	zeroes[] = 0
	
	phi=zeroes;
	phi[1]=phi0;
	dphidx=zeroes;
	dphidx[1]=dphidx0;
	d2phidx2=zeroes;
	mobile_charge_density=zeroes;
	total_charge_density=zeroes;
	
	
	for(position in 1:length(charge_density))
	{
		mobile_charge_density[position]=excess_charge_boltzmann(phi[position],intrinsic_charge_density,Temperature=Temperature)
		total_charge_density[position]=excess_charge_boltzmann(phi[position],intrinsic_charge_density,Temperature=Temperature)+charge_density[position]
		
		
		d2phidx2[position]=-total_charge_density[position]/er/epsilon0
		
		if(position<length(charge_density))
		{
			
			dphidx[position+1]=dphidx[position]+delta_x*d2phidx2[position];
			phi[position+1]=phi[position]+dphidx[position]*delta_x
		}
		
	}
	
	return(phi)
	
	
	
	
}