partition_coefficient_analytical_from_potentials <-
function(phi_m = -0.05, phi_0 = -0.2, Vth=0.025, n_tracer=-1)
{

	
	
	# Required units:
	# surface_charge_density: C/m^2, signed
	# channel_half_width: m
	# n_tracer (valency of the ion for which we want the partition coefficient): no units
	# c0 (bulk salt concentration): mol/L
	
	
	
	# Constants
	
	e0=8.85e-12 # Vacuum permittivity
	
	kB=1.38e-23 # Boltzmann constant
	
	qe=1.6e-19 # Elementary charge
	
	Na=6.022e23 # Avogadros number
	
	
	
	# Normalize charge of polymer to have only 
	
	sign_charge_wall=sign(phi_0)
	
	sign_charge_wall[sign_charge_wall>=0]=1
	
	sign_charge_wall[sign_charge_wall<0]=-1
	
	
	# Make all variables the same length
	
	lmax=max(length (phi_0) ,
		  length( phi_m),
		  length( Vth) , 
		  length( n_tracer))
	
	
	complete_length<-function(x,lmax)
	{
		if(length(x)<lmax)
		{
			x = c(x,rep(x[length(x)],lmax-length(x)))
		}
		
		return(x)
		
	}
	
	phi_0=complete_length(phi_0,lmax)
	phi_m=complete_length(phi_m,lmax)
	Vth=complete_length(Vth,lmax)
	n_tracer=complete_length(n_tracer,lmax)
	
	
	# We need some helper functions here
	# First, linearized cosh function for very small differences
	# Allows to calculate cosh(delta_a)-cosh(a) including cases with excessively small differences between the two and very low a values
	# a is expected to be a single numerical value, delta_a can be a vector
	cosh_delta<-function(a,delta_a)
	{
	# standard case
		
		r<-cosh(a+delta_a)-cosh(a)
		
	# Both a and delta_a very small 
		
		crit_points = abs(delta_a)<1e-4
		
		
		r[crit_points]=sinh(a)*delta_a[crit_points]+cosh(a)*delta_a[crit_points]^2/2
		
		
		
		return(r)
	}
	
	# Second, the actual integration function
	
	average_K<-function(phi_m_single,phi_0_single,n_tracer_single,Vth_single)
	{

		# This function only works for phi_m_single<0 because of the log expression, so
		# we correct for this
		
		# We also suppose that |phi_m_single| <= |phi_0_single|
		
		
		
		if(phi_m_single == phi_0_single)
		{
			return(exp(-n_tracer_single*phi_m_single/Vth_single))
		}
		
		sign_multiplicator=1
		
		if(phi_m_single>0)
		{
			sign_multiplicator=-1
		}
		
		a=phi_m_single*sign_multiplicator/Vth_single
		b=phi_0_single*sign_multiplicator/Vth_single
		
		# support points, log scale
		lg=seq(min(-30,round(log(-sign_multiplicator*phi_m_single,10))-5),0,by=0.01)
		
		delta_from_a = 10^(lg)*(b-a)
		
		y=a+delta_from_a
		
		# Differences between adjacent y values, but for all of them
		
		dy=diff(y)
		
		dy=c(dy[1],dy)
		
		numr=exp(-n_tracer_single*y*sign_multiplicator)/sqrt(cosh_delta(a,delta_from_a))*dy
		
		den=1/sqrt(cosh_delta(a,delta_from_a))*dy
		
		
		
		
		
		
	
		
		return(sum(numr)/sum(den))
	}
	
	
	# Finally, apply the integration to all the stuff
	
	K = vector(mode="numeric",length=length(phi_m))
	
	
	for(index in 1:length(phi_m))
	{
		
			K[index]=average_K(phi_m[index],phi_0[index],n_tracer[index],Vth[index])
		
		
		
	}
	
	
	
	
	
	
	
	
	return(K)


							   
	
	
	
	
	
	
}

