partition_coefficient_analytical_hydrogel <-
function(polymer_concentration=50,strand_diameter=0.6e-9,dry_density_polymer=1500,molar_mass_per_polymer_charge=200,sign_charge_polymer=-1,n_tracer=-1,
c0=1e-3,er=78,T=293,return_details=FALSE)
{
	
	# Required units:
	# polymer_concentration: g/L
	# strand_diameter: m
	# dry_density_polymer: kg/m^3
	# molar_mass_per_polymer_charge: g/moL
	# sign_charge_polymer: no units
	# n_tracer (valency of the ion for which we want the partition coefficient): no units
	# c0 (bulk salt concentration): mol/L
	
	
	
	# Constants
	
	qe=1.6e-19 # Elementary charge
	
	Na=6.022e23 # Avogadros number
	
	
	
	# Normalize charge of polymer to have only 
	
	sign_charge_polymer[sign_charge_polymer>=0]=1
	
	sign_charge_polymer[sign_charge_polymer<0]=-1
	
	
	# Make all variables the same length
	
	lmax=max(length (polymer_concentration) ,
		  length( strand_diameter) , 
	      length( dry_density_polymer) , 
		  length( molar_mass_per_polymer_charge) , 
		  length( sign_charge_polymer) , 
		  length( n_tracer) , 
	      length( c0) , 
	      length( er) , 
	      length( T))
	
	
	complete_length<-function(x,lmax)
	{
		if(length(x)<lmax)
		{
			x = c(x,rep(x[length(x)],lmax-length(x)))
		}
		
		return(x)
		
	}
	
	polymer_concentration=complete_length(polymer_concentration,lmax)
	strand_diameter=complete_length(strand_diameter,lmax)
	dry_density_polymer=complete_length(dry_density_polymer,lmax)
	molar_mass_per_polymer_charge=complete_length(molar_mass_per_polymer_charge,lmax)
	sign_charge_polymer=complete_length(sign_charge_polymer,lmax)
	n_tracer=complete_length(n_tracer,lmax)
	c0=complete_length(c0,lmax)
	er=complete_length(er,lmax)
	T=complete_length(T,lmax)
	
	volume_fraction_polymer = polymer_concentration/dry_density_polymer
	
	r_pore = strand_diameter/volume_fraction_polymer/2
	
	charge_density = 1/2*dry_density_polymer/molar_mass_per_polymer_charge*strand_diameter*Na*qe*1000  # Absolute value; the factor 1000 is because the 
				# the factor 1000 arises because of the units, the molar mass is in g/mol, but the density in kg/m^3
	
	charge_density = sign_charge_polymer*charge_density
	
	
	
	return(partition_coefficient_analytical_nanochannel(surface_charge_density=charge_density,channel_height=2*r_pore,n_tracer=n_tracer,c0=c0,er=er,T=T,return_details=return_details))
	
	
	
	
	
	
}

