partition_coefficient_analytical_nanochannel <-
function(surface_charge_density=-0.1,channel_height=1e-8,n_tracer=-1,
c0=1e-3,er=78,T=293,return_details=FALSE)
{

	
	
	# Required units:
	# surface_charge_density: C/m^2, signed
	# channel_height: m
	# n_tracer (valency of the ion for which we want the partition coefficient): no units
	# c0 (bulk salt concentration): mol/L
	
	# The distribution is symmetric, we merely need the half channel width
	
	channel_half_height=channel_height/2
	
	# Constants
	
	e0=8.85e-12 # Vacuum permittivity
	
	kB=1.38e-23 # Boltzmann constant
	
	qe=1.6e-19 # Elementary charge
	
	Na=6.022e23 # Avogadros number
	
	
	
	# Normalize charge of polymer to have only 
	
	
	
	
	# Make all variables the same length
	
	lmax=max(length (surface_charge_density) ,
		  length( channel_half_height),
		  length( n_tracer) , 
	      length( c0) , 
	      length( er) , 
	      length( T))
	
	
	complete_length<-function(x,lmax)
	{
		if(length(x)<lmax)
		{
			x = c(x,rep(x[length(x)],lmax-length(x)))
		}
		
		return(x)
		
	}
	
	surface_charge_density=complete_length(surface_charge_density,lmax)
	channel_half_height=complete_length(channel_half_height,lmax)
	n_tracer=complete_length(n_tracer,lmax)
	c0=complete_length(c0,lmax)
	er=complete_length(er,lmax)
	T=complete_length(T,lmax)
	
	Vth=kB*T/qe # Thermal voltage
	
	lDebye = sqrt(e0*er*kB*T/2/Na/qe^2/c0/1000)
	
	pots = potentials_analytical_nanochannel(surface_charge_density=surface_charge_density,channel_height=2*channel_half_height,c0=c0,er=er,T=T)

	phi_0 = pots[["phi_0"]]
	
	phi_m = pots[["phi_m"]]
	
	approximation=pots[["approximation"]]
	
	# Now we have phi_m and phi_0, we can integrate
	
	K=partition_coefficient_analytical_from_potentials(phi_m = phi_m, phi_0 = phi_0, Vth=Vth, n_tracer=n_tracer)
	
	
	
	if(return_details){
		
		attr(K,"phi_m")=phi_m
		attr(K,"phi_0")=phi_0	
		attr(K,"approximation")=approximation
		
	}
	
	
	return(K)


							   
	
	
	
	
	
	
}

