solve_poisson_boltzmann <-
function(fixed_charge_concentration,delta_x=1e-11,c_intrinsic=1e-3,Temperature=293,er=78)
{
	
	step_size=1
	max_iter = 50
	
	dphidx0=0
	
	N_avogadro = 6.022e23
	
	elementary_charge = 1.6e-19
	
	epsilon_0 = 8.85e-12
	
	
	
	
	phi0=0
	
	charge_density=fixed_charge_concentration*1000*N_avogadro*elementary_charge
	
	intrinsic_charge_density = c_intrinsic*1000*N_avogadro*elementary_charge
	
	
	
	last_sign=0
	
	for(index in 1:max_iter)
	{
		
		
		
		phi<-integrate_poisson_boltzmann_1D(charge_density=charge_density,delta_x=delta_x,intrinsic_charge_density=intrinsic_charge_density
				,er=er,phi0=phi0,dphidx0=dphidx0,Temperature=Temperature)
		
		
		
		iteration_done=FALSE
		
		last_phi = phi[length(phi)]
		
		if(last_phi==Inf | last_phi==-Inf)
		{
			# First iteration or same sign as before, so we should not diminish the step size
			if(last_sign==0 | sign(last_phi)==last_sign)
			{
				
			} else 	{   
			step_size = step_size/2
			}
			
			last_sign=sign(last_phi)
			
			phi0=phi0-last_sign*step_size
			
			
		} else
		{
		
			lastdphidx = phi[length(phi)]-phi[length(phi)-1]
			
			if(last_sign==0 | sign(lastdphidx)==last_sign)
			{
				
			} else {
				step_size = step_size/2
			}
			
			last_sign=sign(lastdphidx)
			
			phi0=phi0-last_sign*step_size
			

			
			
			
		}
			
		
		
		
	}
	
	
	ret=concentrations_boltzmann(phi,c_intrinsic,Temperature=Temperature)
	ret[["phi"]]=phi
	ret[["fixed_charge_density"]]=fixed_charge_concentration
	ret[["converged"]]=TRUE
	if(phi[length(phi)]==Inf | phi[length(phi)]==-Inf)
	{
		ret[["converged"]]=FALSE
	} else
	{
		if(abs(phi[length(phi)]-phi[length(phi)-1])>0.01*max(abs(diff(phi))))
		{
			ret[["converged"]]=FALSE
		}
		
	}
	
	return(ret)
	
}

