\name{excess_charge_boltzmann}
\alias{excess_charge_boltzmann}

\title{
excess_charge_boltzmann
}
\description{
Excess charge due to the presence of an electric potential in a symmetric monovalent salt, such as KCl. 
}
\usage{
excess_charge_boltzmann(phi,c0,Temperature=293)
}
\arguments{
  \item{phi}{
The electric potential at the location under study. This is relative to a bulk solution where the concentration of both negative and positive ions is equal to \code{c0}
}
  \item{c0}{
Reference concentration at \code{phi=0}
}
  \item{Temperature}{
Absolute temperature in Kelvin
}

}
\details{
At thermodynamic equilibrium, the presence of an electric potential translates into ionic concentrations that are different from bulk, where \code{phi=0} is assumed. Cations will be enriched for negative values of \code{phi}, anions for positive values of \code{phi}, according to \code{c=c0*exp(-phi*z/phi_T)}, where \code{phi_T} is the thermal voltage given by \code{k_B*T/q}, \code{k_B} being the Boltzmann constant, and \code{q} the elementary charge. Further, \code{z=1} for cations and \code{z=-1} for anions. The resulting electrostatic balance leads to a stable equilibrium excess density of mobile charge carriers. This function calculates the imbalance for a given potential \code{phi} and a given bulk monovalent ion concentration of either sign given by \code{c0}. \cr\cr
It should be noted that for reasons of numerical precision, for very small values of phi*z/phi_T, the function uses the linearization \code{c0*(exp(-phi/phi_T)-exp(phi/phi_T))=-2*c0*phi/phi_T}.
}
\value{
Space charge density arising through the equilibrium redistribution of mobile monovalent ions (numerical value)

}
\author{
Thomas Braschler
}
\examples{
# At the thermal potential, the concentrations should be exp(1), exp(-1)
excess_charge_boltzmann(0.025,1)
}
\keyword{ misc }
